@@ -59,6 +59,7 @@ upsell = {
         main: "upsell.css"
       }
     },
+    
     features: {
       //feature infostore
       infostore: {
@@ -104,9 +105,12 @@ upsell = {
           }
         }
       },
+      
       //feature calender
       calendar: {
-        name: ["sidepanel/tasks.share", "sidepanel/contacts.share", "sidepanel/calendar.share", "modules/portal","modules/calendar", "modules/calendar/freebusy", "modules/calendar/team", "modules/calendar/mini_calender", "modules/calendar/new/add_participants", "modules/calendar/new/remove_participants", "modules/calendar/new/add_attachment", "modules/calendar/new/delete_attachment","modules/tasks","modules/tasks/new/add_participants", "modules/tasks/new/remove_participants", "modules/tasks/new/add_attachment", "modules/tasks/new/delete_attachment", "configuration/mail/accounts/new", "sidepanel/premium", "calendar.share", "premium", "tasks.share"],
+        name: ["sidepanel/contacts.share", "sidepanel/calendar.share", "modules/portal","modules/calendar", "modules/calendar/freebusy", "modules/calendar/team",
+               "modules/calendar/mini_calender", "modules/calendar/new/add_participants", "modules/calendar/new/remove_participants", "modules/calendar/new/add_attachment",
+               "modules/calendar/new/delete_attachment", "sidepanel/premium", "calendar.share", "premium"],
         title: _("Enhance your system with &#8222;Teamwork Capabilities&#8220;"),
         intro: _("Make your team successful and cooperate with each other <br>on tasks, shared files and your team-calendar!"),
         list: {
@@ -145,6 +149,7 @@ upsell = {
           }
         }
       },
+      
       //feature mobility
       mobility: {
         name: ["modules/usm/eas", "modules/mobility", "sidepanel/calendar.sync.mobile" , "sidepanel/contacts.sync.mobile", "calendar.sync.mobile", "contacts.subscribe", "contacts.share", "contacts.sync.mobile"],
@@ -264,10 +269,22 @@ upsell = {
   },
 
   init: function (feature, win) {
+
+    // feature tasks (extends from calendar)
+    corewindow.upsell.config.features.tasks = jQuery.extend({
+        name: ["sidepanel/tasks.share","modules/tasks","modules/tasks/new/add_participants", 
+               "modules/tasks/new/remove_participants", "modules/tasks/new/add_attachment",
+               "modules/tasks/new/delete_attachment","tasks.share"]
+    }, corewindow.upsell.config.features.calendar);
+      
+    corewindow.upsell.config.features.configuration = jQuery.extend({
+        name: ["configuration/mail/accounts/new"]
+    }, corewindow.upsell.config.features.calendar);
+
   	corewindow.upsell.config.windows.main = window;
   	corewindow.upsell.config.windows.current = win ? win : window;
 
-  	if(corewindow.upsell.config.windows.current != corewindow.upsell.config.windows.main || !corewindow.upsell.config.windows.current.upsell_init){
+  	if (corewindow.upsell.config.windows.current != corewindow.upsell.config.windows.main || !corewindow.upsell.config.windows.current.upsell_init){
   			corewindow.upsell._init_window();
   	};
 
